@@ -24,3 +24,8 @@ test_that("has `sector` values that are lowercase not uppercase", {
   sectors <- sort(unique(sector_classifications$sector))
   expect_equal(sectors, tolower(sectors))
 })
+
+test_that("debug value does not appear in `nace_classification`", {
+  nace_has_debug_value <- any(grepl("Z", nace_classification$code))
+  expect_false(nace_has_debug_value)
+})
